# cs107-FinalProject 
[![Build Status](https://travis-ci.com/DeriveMeCrazy-AutoDiff/cs107-FinalProject.svg?token=tjHxgXnrZQTw99nTC12g&branch=m1b)](https://travis-ci.com/DeriveMeCrazy-AutoDiff/cs107-FinalProject)
[![codecov](https://codecov.io/gh/DeriveMeCrazy-AutoDiff/cs107-FinalProject/branch/master/graph/badge.svg?token=G7FvPYxS2N)](https://codecov.io/gh/DeriveMeCrazy-AutoDiff/cs107-FinalProject)

### Group #21
John Alling \
Moriya Dechtiar \
Al-Muataz Khalil \
Tianen Liu

## Installing the Dependencies
The package can be installed by navigating to the top level of the repository and running a pip install:
```
pip install .
```
## Usage
The package can then be imported and utilized.
```
import auto_diff_pkg.AutoDiff as AD
```
Please see `docs/demo.ipynb` for demonstrations of the AutoDiff class.
